## Yaml-Pyconf
A simple utility for combining yaml files
and dotenv files into a very basic python config object, 
with config options represented as key-value pairs.

## Current Status:
This was slapped together in a short amount of time to 
meet the need of existing projects. It has not been
reviewed and is not considered to be stable. Testers and
contributors are encouraged 